import codecs
import io
from mo_logs import Log
from mo_times.timer import Timer


def test_simple(filename):
    with Timer("simple time"):
        with codecs.open(filename, "r", encoding="utf-8") as f:
            for line in f:
                id = int(line.split("\t")[0])
                if id % 10000 == 0:
                    Log.note("{{id}}", id=id)


def test_buffered(filename):
    with Timer("buffered time"):
        with codecs.open(filename, "r", encoding="utf-8", buffering=2 ** 25) as f:
            for line in f:
                id = int(line.split("\t")[0])
                if id % 10000 == 0:
                    Log.note("{{id}}", id=id)


def test_io(filename):
    with Timer("io time"):
        with io.open(filename, "r", buffering=2 ** 25) as f:
            for line in f:
                line = line.decode("utf-8")
                id = int(line.split("\t")[0])
                if id % 10000 == 0:
                    Log.note("{{id}}", id=id)


def test_binary(filename, buffering=2 ** 14):
    with Timer("binary time (buffering=={{buffering}})", {"buffering": buffering}):
        remainder = ""
        with io.open(filename, "rb") as f:
            while True:
                block = f.read(buffering)
                if block == "":
                    if remainder == "":
                        return None
                    return remainder
                lines = (remainder + block).split("\n")
                for line in lines[:-1]:
                    line = line.decode("utf-8")
                    id = int(line.split("\t")[0])
                    if id % 10000 == 0:
                        Log.note("{{id}}", id=id)
                remainder = lines[-1]


def test_simple_binary(filename):
    with Timer("simple binary time"):
        with io.open(filename, "rb") as f:
            for line in f:
                line = line.decode("utf-8")
                id = int(line.split("\t")[0])
                if id % 10000 == 0:
                    Log.note("{{id}}", id=id)

test_file = "C:/Users/klahnakoski/git/Datazilla2ElasticSearch/results/recent_old.tab"
test_simple_binary(test_file)
test_binary(test_file, 2 ** 14)
test_binary(test_file, 2 ** 25)
test_io(test_file)
test_simple(test_file)
test_buffered(test_file)



# encoding: utf-8
#
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this file,
# You can obtain one at http://mozilla.org/MPL/2.0/.
#
# Author: Kyle Lahnakoski (kyle@lahnakoski.com)
#


from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

import os

from mo_files import File, join_path
from mo_testing.fuzzytestcase import FuzzyTestCase


par = os.sep + ".."


class TestNames(FuzzyTestCase):

    def test_relative_self(self):
        f = File(".")
        self.assertEqual(f.parent.filename, "..")
        self.assertEqual(f.parent.parent.filename, ".."+par)
        self.assertEqual(f.parent.parent.parent.filename, ".."+par+par)

    def test_relative_self2(self):
        f = File("")
        self.assertEqual(f.parent.filename, "..")
        self.assertEqual(f.parent.parent.filename, ".."+par)
        self.assertEqual(f.parent.parent.parent.filename, ".."+par+par)

    def test_relative_name(self):
        f = File("test.txt")
        self.assertEqual(f.parent.filename, "")
        self.assertEqual(f.parent.parent.filename, "..")
        self.assertEqual(f.parent.parent.parent.filename, ".."+par)

    def test_relative_path(self):
        f = File("a/test.txt")
        self.assertEqual(f.parent.filename, "a")
        self.assertEqual(f.parent.parent.filename, "")
        self.assertEqual(f.parent.parent.parent.filename, "..")

    def test_grandparent(self):
        f = File.new_instance("tests/temp", "../..")
        self.assertEqual(f.filename, ".")

    def test_concat(self):
        f = File.new_instance("tests/temp") / "something" / "or" / "other"
        self.assertTrue(f.abspath.endswith("/tests/temp/something/or/other"))

    def test_empty(self):
        test = join_path("test", "")
        self.assertEqual(test, "test")

    def test_parents(self):
        test = join_path("test", "../../..")
        self.assertEqual(test, "../..")
        self.assertRaises(Exception, join_path, "/test", "../../..")
        self.assertRaises(Exception, join_path, "/test", "../..")

    def test_abs_and_rel_paths(self):
        test1 = join_path('/', 'this/is/a/test/')
        test2 = join_path('.', 'this/is/a/test/')
        test3 = join_path('', 'this/is/a/test/')
        test4 = join_path('/test', '.')
        test5 = join_path('/test', '..', 'this')
        test6 = join_path('/test', '../this')

        self.assertEqual(test1, '/this/is/a/test')
        self.assertEqual(test2, 'this/is/a/test')
        self.assertEqual(test3, 'this/is/a/test')
        self.assertEqual(test4, '/test')
        self.assertEqual(test5, '/this')
        self.assertEqual(test6, '/this')

    def test_abs_and_rel_pathson_file_objects(self):
        test1 = join_path(File('/'), 'this/is/a/test/')
        test2 = join_path(File('.'), 'this/is/a/test/')
        test3 = join_path(File(''), 'this/is/a/test/')
        test4 = join_path(File('/test'), '.')
        test5 = join_path(File('/test'), '..', 'this')
        test6 = join_path(File('/test'), '../this')

        self.assertEqual(test1, '/this/is/a/test')
        self.assertEqual(test2, 'this/is/a/test')
        self.assertEqual(test3, 'this/is/a/test')
        self.assertEqual(test4, '/test')
        self.assertEqual(test5, '/this')
        self.assertEqual(test6, '/this')
